
Puissance4C est un module puissance 4 en console et en couleur, à jouer à 2.

Usage:
```
from puissance4C import p4c
p4c()
```
    
- [Dépot](https://framagit.org/zenjo/puissance4c/tree/master)
- [Home](https://framagit.org/zenjo/puissance4c/wikis/home)



